<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="预警提醒业务">
              <el-select v-model="querys[0].value" style="width:100%" clearable>
                <el-option v-for="item in warnBizList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="预警紧急程度">
              <el-select v-model="querys[1].value" style="width:100%" clearable>
                <el-option v-for="item in msgExigencyList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="有效标志">
              <el-select v-model="querys[2].value" style="width:100%" clearable>
                <el-option v-for="item in flagList" :key="item.value" :label="item.name" :value="item.value" />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="提醒标题">
              <el-input v-model="querys[3].value" clearable placeholder="请输入提醒标题" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed type="index" width="55" label="序号" />
        <!-- <el-table-column  prop="smallPlaceAreaName" min-width="150" label="所属片区"
					show-overflow-tooltip /> -->
        <el-table-column prop="warnBiz" label="预警提醒业务" show-overflow-tooltip />
        <el-table-column prop="warnBizItem" label="预警提醒项" show-overflow-tooltip />
        <!-- <el-table-column
          
          prop="expireDay"
          label="产生预警提醒(天)"
          show-overflow-tooltip
        /> -->
        <!-- <el-table-column
          
          prop="warnRuleMemo"
          label="预警产生说明"
          show-overflow-tooltip
        />
        <el-table-column
          
          prop="produceCyle"
          label="预警提醒生产周期"
          show-overflow-tooltip
        /> -->
        <el-table-column prop="title" label="提醒标题" show-overflow-tooltip />
        <el-table-column prop="msgExigency" label="预警紧急程度" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-tag v-if="scope.row.msgExigency === '1'" type="success">普通</el-tag>
            <el-tag v-else-if="scope.row.msgExigency === '2'" type="warning">一般较急</el-tag>
            <el-tag v-else-if="scope.row.msgExigency === '3'" type="danger">紧急</el-tag>
          </template>
        </el-table-column>
        <el-table-column prop="remindType" label="提醒方式" show-overflow-tooltip />
        <el-table-column prop="remindRange" label="通知范围" show-overflow-tooltip />
        <el-table-column prop="flag" label="有效标志" show-overflow-tooltip />
        <el-table-column align="right" width="100px" label="操作" :index="999">
          <template slot-scope="scope">
            <el-button v-if="scope.row.flag !== '有效'" size="mini" type="primary" plain
              @click="Activate(scope.row)">启用</el-button>
            <el-button v-if="scope.row.flag !== '无效'" size="mini" type="danger" plain
              @click="Disable(scope.row)">禁用</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <CmgtTSaftyWorkConfFormDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CmgtTSaftyWorkConfApi from '@/views/Manage/saftyDanger/api/CmgtTSaftyWorkConfApi'
import CmgtTSaftyWorkConfFormDialog from '@/views/Manage/saftyDanger/components/CmgtTSaftyWorkConfFormDialog'

export default {
  name: 'CmgtSaftyDangerUnitManage',
  components: {
    CmgtTSaftyWorkConfFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyDangerUnit/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warnBiz',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'msgExigency',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'flag',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'title',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      types: [],
      sorter: [
        {
          direction: 'ASC',
          property: ''
        }
      ]
      // levels:[]
    }
  },
  created() {
    this.types = dictContracts.getDictItemsFromCache('cmgt_aqyhpcdwlb')
    this.warnBizList = dictUtils.getDictItemsFromCache('yjtxyw')
    this.warnBizItemList = dictUtils.getDictItemsFromCache('yjtxx')
    this.warnRuleList = dictUtils.getDictItemsFromCache('yjgz')
    this.msgExigencyList = dictUtils.getDictItemsFromCache('yjjjcd')
    this.remindTypeList = dictUtils.getDictItemsFromCache('yjtxfs')
    this.remindRangeList = dictUtils.getDictItemsFromCache('tzfw')
    this.flagList = dictUtils.getDictItemsFromCache('yxbz')
    // this.levels = dictContracts.getDictItemsFromCache('cmgt_aqyhfxjb')
  },
  mounted() { },
  methods: {
    //启用
    Activate(row) {
      //   console.log(row)
      CmgtTSaftyWorkConfApi.startUpJob(row.id, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: '启用成功',
            duration: 2000
          })
          this.loadData()
        }
      })
    },
    //禁用
    Disable(row) {
      //   console.log(row)
      CmgtTSaftyWorkConfApi.stopJob(row.id, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: '禁用成功',
            duration: 2000
          })
          this.loadData()
        }
      })
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      CmgtTSaftyWorkConfApi.cmgtWorkWarnConfQuery(this.queryParam, res => {
        console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          // console.log(item)
          this.warnBizList.forEach(val => {
            if (item.warnBiz == val.value) {
              item.warnBiz = val.name
            }
          })
          this.warnBizItemList.forEach(val => {
            if (item.warnBizItem == val.value) {
              item.warnBizItem = val.name
            }
          })
          //   this.msgExigencyList.forEach(val => {
          //     if (item.msgExigency == val.value) {
          //       item.msgExigency = val.name
          //     }
          //   })
          this.remindTypeList.forEach(val => {
            if (item.remindType == val.value) {
              item.remindType = val.name
            }
          })
          this.remindRangeList.forEach(val => {
            if (item.remindRange == val.value) {
              item.remindRange = val.name
            }
          })
          this.flagList.forEach(val => {
            if (item.flag == val.value) {
              item.flag = val.name
            }
          })
          //   item['emphasisTypeName'] = ''
          //   this.zddwflList.forEach(val => {
          //     if (item.emphasisType) {
          //       item.emphasisType.split(',').forEach((e, ei) => {
          //         if (e == val.value) {
          //           if (ei + 1 < item.emphasisType.split(',').length) {
          //             item['emphasisTypeName'] += val.name + ','
          //           } else {
          //             item['emphasisTypeName'] += val.name
          //           }
          //         }
          //       })
          //     }
          //   })
          //   this.fxjbList.forEach(val => {
          //     if (item.riskLevel == val.value) {
          //       item['riskLevelName'] = val.name
          //     }
          //   })
          //   this.rlzlList.forEach(val => {
          //     if (item.fuelType == val.value) {
          //       item['fuelTypeName'] = val.name
          //     }
          //   })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleDelete() {
      //   console.log(this.multipleSelection)
      CmgtTSaftyWorkConfApi.deleteCmgtSaftyDangerUnit(this.multipleSelection)
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // 修改
    handleUpdate(row) {
      //   console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    formartTyepName(row, column, cellValue, index) {
      var obj = this.types.find(function (item) {
        if (item.value === row.type) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
